@@ -8,7 +8,8 @@ import (
 
 // A ReadOnlySystem is a system that may only be read from.
 type ReadOnlySystem struct {
-	noUpdateSystemMixin
+	NoUpdateSystemMixin
+
 	system System
 }
 
