@@ -9,8 +9,9 @@ import (
 
 // A TarWriterSystem is a System that writes to a tar archive.
 type TarWriterSystem struct {
-	emptySystemMixin
-	noUpdateSystemMixin
+	EmptySystemMixin
+	NoUpdateSystemMixin
+
 	tarWriter      *tar.Writer
 	headerTemplate tar.Header
 }
