@@ -11,8 +11,8 @@ import (
 	"github.com/alecthomas/assert/v2"
 	"github.com/twpayne/go-vfs/v5"
 
-	"github.com/twpayne/chezmoi/internal/chezmoi"
-	"github.com/twpayne/chezmoi/internal/chezmoitest"
+	"chezmoi.io/chezmoi/internal/chezmoi"
+	"chezmoi.io/chezmoi/internal/chezmoitest"
 )
 
 func TestKeepassxcParseOutput(t *testing.T) {
